"""Provides an object representing the current 'version' or 'release'
of PyCrust as a whole.  Individual classes, such as the shell, filling
and interpreter, each have a revision property based on the CVS
Revision."""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: version.py,v 1.8.2.5 2003/03/20 23:14:31 RD Exp $"
__revision__ = "$Revision: 1.8.2.5 $"[11:-2]

VERSION = '0.9'
 
