( cd usr/bin ; rm -rf wx-config )
( cd usr/bin ; ln -sf /usr/lib/wx/config/gtk2-unicode-debug-2.5 wx-config )
( cd usr/lib ; rm -rf libwx_baseud-2.5.so )
( cd usr/lib ; ln -sf libwx_baseud-2.5.so.3 libwx_baseud-2.5.so )
( cd usr/lib ; rm -rf libwx_baseud-2.5.so.3 )
( cd usr/lib ; ln -sf libwx_baseud-2.5.so.3.0.0 libwx_baseud-2.5.so.3 )
( cd usr/lib ; rm -rf libwx_baseud_net-2.5.so )
( cd usr/lib ; ln -sf libwx_baseud_net-2.5.so.3 libwx_baseud_net-2.5.so )
( cd usr/lib ; rm -rf libwx_baseud_net-2.5.so.3 )
( cd usr/lib ; ln -sf libwx_baseud_net-2.5.so.3.0.0 libwx_baseud_net-2.5.so.3 )
( cd usr/lib ; rm -rf libwx_baseud_xml-2.5.so )
( cd usr/lib ; ln -sf libwx_baseud_xml-2.5.so.3 libwx_baseud_xml-2.5.so )
( cd usr/lib ; rm -rf libwx_baseud_xml-2.5.so.3 )
( cd usr/lib ; ln -sf libwx_baseud_xml-2.5.so.3.0.0 libwx_baseud_xml-2.5.so.3 )
( cd usr/lib ; rm -rf libwx_gtk2ud_adv-2.5.so )
( cd usr/lib ; ln -sf libwx_gtk2ud_adv-2.5.so.3 libwx_gtk2ud_adv-2.5.so )
( cd usr/lib ; rm -rf libwx_gtk2ud_adv-2.5.so.3 )
( cd usr/lib ; ln -sf libwx_gtk2ud_adv-2.5.so.3.0.0 libwx_gtk2ud_adv-2.5.so.3 )
( cd usr/lib ; rm -rf libwx_gtk2ud_core-2.5.so )
( cd usr/lib ; ln -sf libwx_gtk2ud_core-2.5.so.3 libwx_gtk2ud_core-2.5.so )
( cd usr/lib ; rm -rf libwx_gtk2ud_core-2.5.so.3 )
( cd usr/lib ; ln -sf libwx_gtk2ud_core-2.5.so.3.0.0 libwx_gtk2ud_core-2.5.so.3 )
( cd usr/lib ; rm -rf libwx_gtk2ud_gl-2.5.so )
( cd usr/lib ; ln -sf libwx_gtk2ud_gl-2.5.so.3 libwx_gtk2ud_gl-2.5.so )
( cd usr/lib ; rm -rf libwx_gtk2ud_gl-2.5.so.3 )
( cd usr/lib ; ln -sf libwx_gtk2ud_gl-2.5.so.3.0.0 libwx_gtk2ud_gl-2.5.so.3 )
( cd usr/lib ; rm -rf libwx_gtk2ud_html-2.5.so )
( cd usr/lib ; ln -sf libwx_gtk2ud_html-2.5.so.3 libwx_gtk2ud_html-2.5.so )
( cd usr/lib ; rm -rf libwx_gtk2ud_html-2.5.so.3 )
( cd usr/lib ; ln -sf libwx_gtk2ud_html-2.5.so.3.0.0 libwx_gtk2ud_html-2.5.so.3 )
( cd usr/lib ; rm -rf libwx_gtk2ud_xrc-2.5.so )
( cd usr/lib ; ln -sf libwx_gtk2ud_xrc-2.5.so.3 libwx_gtk2ud_xrc-2.5.so )
( cd usr/lib ; rm -rf libwx_gtk2ud_xrc-2.5.so.3 )
( cd usr/lib ; ln -sf libwx_gtk2ud_xrc-2.5.so.3.0.0 libwx_gtk2ud_xrc-2.5.so.3 )
( cd usr/lib/wxPython/lib ; rm -rf libwx_gtkd-2.4.so )
( cd usr/lib/wxPython/lib ; ln -sf libwx_gtkd-2.4.so.0.0.0 libwx_gtkd-2.4.so )
( cd usr/lib/wxPython/lib ; rm -rf libwx_gtkd-2.4.so.0 )
( cd usr/lib/wxPython/lib ; ln -sf libwx_gtkd-2.4.so.0.0.0 libwx_gtkd-2.4.so.0 )
( cd usr/lib/wxPython/lib ; rm -rf libwx_gtkd_gl-2.4.so )
( cd usr/lib/wxPython/lib ; ln -sf libwx_gtkd_gl-2.4.so.0.0.0 libwx_gtkd_gl-2.4.so )
( cd usr/lib/wxPython/lib ; rm -rf libwx_gtkd_gl-2.4.so.0 )
( cd usr/lib/wxPython/lib ; ln -sf libwx_gtkd_gl-2.4.so.0.0.0 libwx_gtkd_gl-2.4.so.0 )
