"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Functions.py,v 1.1.2.2 2003/03/20 23:14:27 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx


def ArtProvider_GetBitmap():
    """"""
    pass

def ArtProvider_GetIcon():
    """"""
    pass

def ArtProvider_PopProvider():
    """"""
    pass

def ArtProvider_PushProvider():
    """"""
    pass

def ArtProvider_RemoveProvider():
    """"""
    pass

def BeginBusyCursor():
    """"""
    pass

def Bell():
    """"""
    pass

def BitmapFromBits():
    """"""
    pass

def BitmapFromIcon():
    """"""
    pass

def BitmapFromImage():
    """"""
    pass

def BitmapFromXPMData():
    """"""
    pass

def BufferedDCInternalBuffer():
    """"""
    pass

def Button_GetDefaultSize():
    """"""
    pass

def CallAfter(callable, *args, **kw):
    """Call the specified function after the current and pending event
    handlers have been completed.  This is also good for making GUI
    method calls from non-GUI threads."""
    pass

def Caret_GetBlinkTime():
    """"""
    pass

def Caret_SetBlinkTime():
    """"""
    pass

def ClientDisplayRect():
    """"""
    pass

def ColourDisplay():
    """"""
    pass

def ConfigBase_Create():
    """"""
    pass

def ConfigBase_DontCreateOnDemand():
    """"""
    pass

def ConfigBase_Get():
    """"""
    pass

def ConfigBase_Set():
    """"""
    pass

def CreateFileTipProvider():
    """"""
    pass

def CustomDataFormat():
    """"""
    pass

def DLG_PNT():
    """"""
    pass

def DLG_SZE():
    """"""
    pass

def DateSpan_Day():
    """"""
    pass

def DateSpan_Days():
    """"""
    pass

def DateSpan_Month():
    """"""
    pass

def DateSpan_Months():
    """"""
    pass

def DateSpan_Week():
    """"""
    pass

def DateSpan_Weeks():
    """"""
    pass

def DateSpan_Year():
    """"""
    pass

def DateSpan_Years():
    """"""
    pass

def DateTimeFromDMY():
    """"""
    pass

def DateTimeFromHMS():
    """"""
    pass

def DateTimeFromJDN():
    """"""
    pass

def DateTimeFromTimeT():
    """"""
    pass

def DateTime_ConvertYearToBC():
    """"""
    pass

def DateTime_GetAmPmStrings():
    """"""
    pass

def DateTime_GetBeginDST():
    """"""
    pass

def DateTime_GetCentury():
    """"""
    pass

def DateTime_GetCountry():
    """"""
    pass

def DateTime_GetCurrentMonth():
    """"""
    pass

def DateTime_GetCurrentYear():
    """"""
    pass

def DateTime_GetEndDST():
    """"""
    pass

def DateTime_GetMonthName():
    """"""
    pass

def DateTime_GetNumberOfDaysInMonth():
    """"""
    pass

def DateTime_GetNumberOfDaysinYear():
    """"""
    pass

def DateTime_GetWeekDayName():
    """"""
    pass

def DateTime_IsDSTApplicable():
    """"""
    pass

def DateTime_IsLeapYear():
    """"""
    pass

def DateTime_IsWestEuropeanCountry():
    """"""
    pass

def DateTime_Now():
    """"""
    pass

def DateTime_SetCountry():
    """"""
    pass

def DateTime_Today():
    """"""
    pass

def DateTime_UNow():
    """"""
    pass

def DirSelector():
    """"""
    pass

def DisplayDepth():
    """"""
    pass

def DisplaySize():
    """"""
    pass

def DisplaySizeMM():
    """"""
    pass

def DragIcon():
    """"""
    pass

def DragListItem():
    """"""
    pass

def DragString():
    """"""
    pass

def DragTreeItem():
    """"""
    pass

def EmptyBitmap():
    """"""
    pass

def EmptyIcon():
    """"""
    pass

def EmptyImage():
    """"""
    pass

def EnableTopLevelWindows():
    """"""
    pass

def EncodingConverter_GetAllEquivalents():
    """"""
    pass

def EncodingConverter_GetPlatformEquivalents():
    """"""
    pass

def EndBusyCursor():
    """"""
    pass

def Execute():
    """"""
    pass

def FileSelector():
    """"""
    pass

def FileSystem_AddHandler():
    """"""
    pass

def FileSystem_CleanUpHandlers():
    """"""
    pass

def FileTypeInfoSequence():
    """"""
    pass

def FileType_ExpandCommand():
    """"""
    pass

def FindWindowAtPoint():
    """"""
    pass

def FindWindowById(id, parent=wx.NULL):
    """"""
    pass

def FindWindowByLabel(label, parent=wx.NULL):
    """"""
    pass

def FindWindowByName(name, parent=wx.NULL):
    """"""
    pass

def FontFromNativeInfo():
    """"""
    pass

def FontMapper_Get():
    """"""
    pass

def FontMapper_GetDefaultConfigPath():
    """"""
    pass

def FontMapper_GetEncodingDescription():
    """"""
    pass

def FontMapper_GetEncodingName():
    """"""
    pass

def FontMapper_Set():
    """"""
    pass

def Font_GetDefaultEncoding():
    """"""
    pass

def Font_SetDefaultEncoding():
    """"""
    pass

def GenericFindWindowAtPoint():
    """"""
    pass

def GetAccelFromString():
    """"""
    pass

def GetActiveWindow():
    """"""
    pass

def GetApp():
    """"""
    pass

def GetClientDisplayRect():
    """"""
    pass

def GetCurrentId():
    """"""
    pass

def GetCurrentTime():
    """"""
    pass

def GetDisplayDepth():
    """"""
    pass

def GetDisplaySize():
    """"""
    pass

def GetDisplaySizeMM():
    """"""
    pass

def GetElapsedTime():
    """"""
    pass

def GetEmailAddress():
    """"""
    pass

def GetFullHostName():
    """"""
    pass

def GetHomeDir():
    """"""
    pass

def GetHostName():
    """"""
    pass

def GetLocalTime():
    """"""
    pass

def GetLocalTimeMillis():
    """"""
    pass

def GetLocale():
    """"""
    pass

def GetMousePosition():
    """"""
    pass

def GetNumberFromUser():
    """"""
    pass

def GetOsDescription():
    """"""
    pass

def GetOsVersion():
    """"""
    pass

def GetPasswordFromUser():
    """"""
    pass

def GetProcessId():
    """"""
    pass

def GetSingleChoice():
    """"""
    pass

def GetSingleChoiceIndex():
    """"""
    pass

def GetTextFromUser():
    """"""
    pass

def GetTopLevelParent():
    """"""
    pass

def GetTranslation():
    """"""
    pass

def GetUTCTime():
    """"""
    pass

def GetUserHome():
    """"""
    pass

def GetUserId():
    """"""
    pass

def GetUserName():
    """"""
    pass

def IconBundleFromFile():
    """"""
    pass

def IconBundleFromIcon():
    """"""
    pass

def IconFromBitmap():
    """"""
    pass

def IconFromXPMData():
    """"""
    pass

def ImageFromBitmap():
    """"""
    pass

def ImageFromData():
    """"""
    pass

def ImageFromMime():
    """"""
    pass

def ImageFromStream():
    """"""
    pass

def ImageFromStreamMime():
    """"""
    pass

def Image_AddHandler():
    """"""
    pass

def Image_CanRead():
    """"""
    pass

def Image_CanReadStream():
    """"""
    pass

def Image_GetImageCount():
    """"""
    pass

def Image_InsertHandler():
    """"""
    pass

def Image_RemoveHandler():
    """"""
    pass

def InitAllImageHandlers():
    """"""
    pass

def IntersectRect():
    """"""
    pass

def IsBusy():
    """"""
    pass

def IsDragResultOk():
    """"""
    pass

def LoadFileSelector():
    """"""
    pass

def Locale_AddCatalogLookupPathPrefix():
    """"""
    pass

def Locale_AddLanguage():
    """"""
    pass

def Locale_GetLanguageInfo():
    """"""
    pass

def Locale_GetSystemEncoding():
    """"""
    pass

def Locale_GetSystemEncodingName():
    """"""
    pass

def Locale_GetSystemLanguage():
    """"""
    pass

def LogDebug():
    """"""
    pass

def LogError():
    """"""
    pass

def LogFatalError():
    """"""
    pass

def LogGeneric():
    """"""
    pass

def LogInfo():
    """"""
    pass

def LogMessage():
    """"""
    pass

def LogStatus():
    """"""
    pass

def LogStatusFrame():
    """"""
    pass

def LogSysError():
    """"""
    pass

def LogTrace():
    """"""
    pass

def LogTraceMask():
    """"""
    pass

def LogVerbose():
    """"""
    pass

def LogWarning():
    """"""
    pass

def Log_AddTraceMask():
    """"""
    pass

def Log_ClearTraceMasks():
    """"""
    pass

def Log_DontCreateOnDemand():
    """"""
    pass

def Log_EnableLogging():
    """"""
    pass

def Log_FlushActive():
    """"""
    pass

def Log_GetActiveTarget():
    """"""
    pass

def Log_GetLogLevel():
    """"""
    pass

def Log_GetTimestamp():
    """"""
    pass

def Log_GetTraceMask():
    """"""
    pass

def Log_GetTraceMasks():
    """"""
    pass

def Log_IsAllowedTraceMask():
    """"""
    pass

def Log_IsEnabled():
    """"""
    pass

def Log_OnLog():
    """"""
    pass

def Log_RemoveTraceMask():
    """"""
    pass

def Log_Resume():
    """"""
    pass

def Log_SetActiveTarget():
    """"""
    pass

def Log_SetLogLevel():
    """"""
    pass

def Log_SetTimestamp():
    """"""
    pass

def Log_SetTraceMask():
    """"""
    pass

def Log_SetVerbose():
    """"""
    pass

def Log_Suspend():
    """"""
    pass

def MaskColour():
    """"""
    pass

def MemoryDCFromDC():
    """"""
    pass

def MemoryFSHandler_AddFile():
    """"""
    pass

def MemoryFSHandler_RemoveFile():
    """"""
    pass

def MenuItem_GetLabelFromText():
    """"""
    pass

def MessageBox():
    """"""
    pass

def MimeTypesManager_IsOfType():
    """"""
    pass

def MutexGuiEnter():
    """"""
    pass

def MutexGuiLeave():
    """"""
    pass

def NamedColour():
    """"""
    pass

def NamedColour():
    """"""
    pass

def NewEventType():
    """"""
    pass

def NewId():
    """"""
    pass

def Now():
    """"""
    pass

def NullFileTypeInfo():
    """"""
    pass

def Point2DDoubleCopy():
    """"""
    pass

def Point2DDoubleFromPoint():
    """"""
    pass

def PostEvent():
    """"""
    pass

def PostScriptDC_GetResolution():
    """"""
    pass

def PostScriptDC_SetResolution():
    """"""
    pass

def PreBitmapButton():
    """"""
    pass

def PreButton():
    """"""
    pass

def PreCheckBox():
    """"""
    pass

def PreCheckListBox():
    """"""
    pass

def PreChoice():
    """"""
    pass

def PreComboBox():
    """"""
    pass

def PreControl():
    """"""
    pass

def PreDialog():
    """"""
    pass

def PreDirFilterListCtrl():
    """"""
    pass

def PreFindReplaceDialog():
    """"""
    pass

def PreFrame():
    """"""
    pass

def PreGauge():
    """"""
    pass

def PreGenericDirCtrl():
    """"""
    pass

def PreListBox():
    """"""
    pass

def PreListCtrl():
    """"""
    pass

def PreListView():
    """"""
    pass

def PreMDIChildFrame():
    """"""
    pass

def PreMDIClientWindow():
    """"""
    pass

def PreMDIParentFrame():
    """"""
    pass

def PreMiniFrame():
    """"""
    pass

def PreNotebook():
    """"""
    pass

def PrePanel():
    """"""
    pass

def PrePopupTransientWindow():
    """"""
    pass

def PrePopupWindow():
    """"""
    pass

def PreRadioBox():
    """"""
    pass

def PreRadioButton():
    """"""
    pass

def PreSashLayoutWindow():
    """"""
    pass

def PreSashWindow():
    """"""
    pass

def PreScrollBar():
    """"""
    pass

def PreScrolledWindow():
    """"""
    pass

def PreSingleInstanceChecker():
    """"""
    pass

def PreSlider():
    """"""
    pass

def PreSpinButton():
    """"""
    pass

def PreSpinCtrl():
    """"""
    pass

def PreSplitterWindow():
    """"""
    pass

def PreStaticBitmap():
    """"""
    pass

def PreStaticBox():
    """"""
    pass

def PreStaticLine():
    """"""
    pass

def PreStaticText():
    """"""
    pass

def PreStatusBar():
    """"""
    pass

def PreTextCtrl():
    """"""
    pass

def PreToggleButton():
    """"""
    pass

def PreToolBar():
    """"""
    pass

def PreToolBarSimple():
    """"""
    pass

def PreTopLevelWindow():
    """"""
    pass

def PreTreeCtrl():
    """"""
    pass

def PreWindow():
    """"""
    pass

def Process_Exists():
    """"""
    pass

def Process_Kill():
    """"""
    pass

def Process_Open():
    """"""
    pass

def PyTypeCast(obj, typeStr):
    """This helper function will take a wxPython object and convert it
    to another wxPython object type.  This will not be able to create
    objects that are derived from wxPython classes by the user, only
    those that are actually part of wxPython and directly corespond to
    C++ objects.

    This is useful in situations where some method returns a generic
    type such as wxWindow, but you know that it is actually some
    derived type such as a TextCtrl.  You can't call TextCtrl
    specific methods on a Window object, but you can use this
    function to create a TextCtrl object that will pass the same
    pointer to the C++ code.  You use it like this:

       textCtrl = PyTypeCast(window, "TextCtrl")

    WARNING:  Using this function to type cast objects into types that
              they are not is not recommended and is likely to cause
              your program to crash...  Hard."""
    pass

def Py_isinstance(obj, klasses):
    """An isinstance for Python < 2.2 that can check a sequence of
    class objects like the one in 2.2 can."""
    pass

def RegionFromPoints():
    """"""
    pass

def RegisterId():
    """"""
    pass

## def RunLater(callable, *args, **kw):
##     """An alias for CallAfter."""
##     pass

RunLater = CallAfter

def SafeShowMessage():
    """"""
    pass

def SafeYield():
    """"""
    pass

def SaveFileSelector():
    """"""
    pass

def SetCursor():
    """"""
    pass

def Shell():
    """"""
    pass

def ShowTip():
    """"""
    pass

def Shutdown():
    """"""
    pass

def Sleep():
    """"""
    pass

def StartTimer():
    """"""
    pass

def StockCursor():
    """"""
    pass

def StripMenuCodes():
    """"""
    pass

def SysErrorCode():
    """"""
    pass

def SysErrorMsg():
    """"""
    pass

def SystemSettings_GetColour():
    """"""
    pass

def SystemSettings_GetFont():
    """"""
    pass

def SystemSettings_GetMetric():
    """"""
    pass

def SystemSettings_GetScreenType():
    """"""
    pass

def SystemSettings_GetColour():
    """"""
    pass

def SystemSettings_GetFont():
    """"""
    pass

def SystemSettings_GetMetric():
    """"""
    pass

def SystemSettings_HasFeature():
    """"""
    pass

def SystemSettings_SetScreenType():
    """"""
    pass

def TextAttr_Combine():
    """"""
    pass

def Thread_IsMain():
    """"""
    pass

def TimeSpan_Day():
    """"""
    pass

def TimeSpan_Days():
    """"""
    pass

def TimeSpan_Hour():
    """"""
    pass

def TimeSpan_Hours():
    """"""
    pass

def TimeSpan_Minute():
    """"""
    pass

def TimeSpan_Minutes():
    """"""
    pass

def TimeSpan_Second():
    """"""
    pass

def TimeSpan_Seconds():
    """"""
    pass

def TimeSpan_Week():
    """"""
    pass

def TimeSpan_Weeks():
    """"""
    pass

def ToolTip_Enable():
    """"""
    pass

def ToolTip_SetDelay():
    """"""
    pass

def Usleep():
    """"""
    pass

def Validator_IsSilent():
    """"""
    pass

def Validator_SetBellOnError():
    """"""
    pass

def WakeUpIdle():
    """"""
    pass

def WaveData():
    """"""
    pass

def Window_FindFocus():
    """"""
    pass

def Window_GetCapture():
    """"""
    pass

def Window_NewControlId():
    """"""
    pass

def Window_NextControlId():
    """"""
    pass

def Window_PrevControlId():
    """"""
    pass

def Yield():
    """"""
    pass

def YieldIfNeeded():
    """"""
    pass
