__cvsid__ = "$Id: DateTime.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx


class DateSpan:
    """"""

    def Add(self):
        """"""
        pass

    def GetDays(self):
        """"""
        pass

    def GetMonths(self):
        """"""
        pass

    def GetTotalDays(self):
        """"""
        pass

    def GetWeeks(self):
        """"""
        pass

    def GetYears(self):
        """"""
        pass

    def Multiply(self):
        """"""
        pass

    def Neg(self):
        """"""
        pass

    def SetDays(self):
        """"""
        pass

    def SetMonths(self):
        """"""
        pass

    def SetWeeks(self):
        """"""
        pass

    def SetYears(self):
        """"""
        pass

    def Subtract(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __mul__(self):
        """"""
        pass

    def __neg__(self):
        """"""
        pass

    def __rmul__(self):
        """"""
        pass

    def __sub__(self):
        """"""
        pass


class DateTime:
    """"""

    def AddDS(self):
        """"""
        pass

    def AddTS(self):
        """"""
        pass

    def Format(self):
        """"""
        pass

    def FormatDate(self):
        """"""
        pass

    def FormatISODate(self):
        """"""
        pass

    def FormatISOTime(self):
        """"""
        pass

    def FormatTime(self):
        """"""
        pass

    def GetDay(self):
        """"""
        pass

    def GetDayOfYear(self):
        """"""
        pass

    def GetHour(self):
        """"""
        pass

    def GetJDN(self):
        """"""
        pass

    def GetJulianDayNumber(self):
        """"""
        pass

    def GetLastMonthDay(self):
        """"""
        pass

    def GetLastWeekDay(self):
        """"""
        pass

    def GetMJD(self):
        """"""
        pass

    def GetMillisecond(self):
        """"""
        pass

    def GetMinute(self):
        """"""
        pass

    def GetModifiedJulianDayNumber(self):
        """"""
        pass

    def GetMonth(self):
        """"""
        pass

    def GetNextWeekDay(self):
        """"""
        pass

    def GetPrevWeekDay(self):
        """"""
        pass

    def GetRataDie(self):
        """"""
        pass

    def GetSecond(self):
        """"""
        pass

    def GetTicks(self):
        """"""
        pass

    def GetWeek(self):
        """"""
        pass

    def GetWeekDay(self):
        """"""
        pass

    def GetWeekDayInSameWeek(self):
        """"""
        pass

    def GetWeekOfMonth(self):
        """"""
        pass

    def GetWeekOfYear(self):
        """"""
        pass

    def GetYear(self):
        """"""
        pass

    def GetYearDay(self):
        """"""
        pass

    def IsBetween(self):
        """"""
        pass

    def IsDST(self):
        """"""
        pass

    def IsEarlierThan(self):
        """"""
        pass

    def IsEqualTo(self):
        """"""
        pass

    def IsEqualUpTo(self):
        """"""
        pass

    def IsLaterThan(self):
        """"""
        pass

    def IsSameDate(self):
        """"""
        pass

    def IsSameTime(self):
        """"""
        pass

    def IsStrictlyBetween(self):
        """"""
        pass

    def IsValid(self):
        """"""
        pass

    def IsWorkDay(self):
        """"""
        pass

    def MakeGMT(self):
        """"""
        pass

    def MakeTimezone(self):
        """"""
        pass

    def ParseDate(self):
        """"""
        pass

    def ParseDateTime(self):
        """"""
        pass

    def ParseFormat(self):
        """"""
        pass

    def ParseRfc822Date(self):
        """"""
        pass

    def ParseTime(self):
        """"""
        pass

    def ResetTime(self):
        """"""
        pass

    def Set(self):
        """"""
        pass

    def SetDay(self):
        """"""
        pass

    def SetHMS(self):
        """"""
        pass

    def SetHour(self):
        """"""
        pass

    def SetJDN(self):
        """"""
        pass

    def SetMillisecond(self):
        """"""
        pass

    def SetMinute(self):
        """"""
        pass

    def SetMonth(self):
        """"""
        pass

    def SetSecond(self):
        """"""
        pass

    def SetTimeT(self):
        """"""
        pass

    def SetToCurrent(self):
        """"""
        pass

    def SetToLastMonthDay(self):
        """"""
        pass

    def SetToLastWeekDay(self):
        """"""
        pass

    def SetToNextWeekDay(self):
        """"""
        pass

    def SetToPrevWeekDay(self):
        """"""
        pass

    def SetToTheWeek(self):
        """"""
        pass

    def SetToWeekDay(self):
        """"""
        pass

    def SetToWeekDayInSameWeek(self):
        """"""
        pass

    def SetToYearDay(self):
        """"""
        pass

    def SetYear(self):
        """"""
        pass

    def Subtract(self):
        """"""
        pass

    def SubtractDS(self):
        """"""
        pass

    def SubtractTS(self):
        """"""
        pass

    def ToGMT(self):
        """"""
        pass

    def ToTimezone(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __cmp__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __str__(self):
        """"""
        pass

    def __sub__(self):
        """"""
        pass

    def _wxDateTimePtr__add__DS(self):
        """"""
        pass

    def _wxDateTimePtr__add__TS(self):
        """"""
        pass

    def _wxDateTimePtr__sub__DS(self):
        """"""
        pass

    def _wxDateTimePtr__sub__DT(self):
        """"""
        pass

    def _wxDateTimePtr__sub__TS(self):
        """"""
        pass


class TimeSpan:
    """"""

    def Abs(self):
        """"""
        pass

    def Add(self):
        """"""
        pass

    def Format(self):
        """"""
        pass

    def GetDays(self):
        """"""
        pass

    def GetHours(self):
        """"""
        pass

    def GetMilliseconds(self):
        """"""
        pass

    def GetMinutes(self):
        """"""
        pass

    def GetSeconds(self):
        """"""
        pass

    def GetWeeks(self):
        """"""
        pass

    def IsEqualTo(self):
        """"""
        pass

    def IsLongerThan(self):
        """"""
        pass

    def IsNegative(self):
        """"""
        pass

    def IsNull(self):
        """"""
        pass

    def IsPositive(self):
        """"""
        pass

    def IsShorterThan(self):
        """"""
        pass

    def Multiply(self):
        """"""
        pass

    def Neg(self):
        """"""
        pass

    def Subtract(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __cmp__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __mul__(self):
        """"""
        pass

    def __neg__(self):
        """"""
        pass

    def __rmul__(self):
        """"""
        pass

    def __sub__(self):
        """"""
        pass


