#----------------------------------------------------------------------
# Name:        wxPython.lib.editor
# Purpose:     A package containing a colourizable text editror
#
# Author:      Robin Dunn
#
# Created:     30-Dec-1999
# RCS-ID:      $Id: __init__.py,v 1.5 2001/12/01 02:22:57 RD Exp $
# Copyright:   (c) 1999 by Total Control Software
# Licence:     wxWindows license
#----------------------------------------------------------------------

# This file makes this directory into a Python package


# import the main classes into the package namespace.
from editor    import wxEditor
