"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: SashSplitter.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx
from Window import Window


class SashWindow(Window):
    """"""

    def Create(self):
        """"""
        pass

    def GetDefaultBorderSize(self):
        """"""
        pass

    def GetEdgeMargin(self):
        """"""
        pass

    def GetExtraBorderSize(self):
        """"""
        pass

    def GetMaximumSizeX(self):
        """"""
        pass

    def GetMaximumSizeY(self):
        """"""
        pass

    def GetMinimumSizeX(self):
        """"""
        pass

    def GetMinimumSizeY(self):
        """"""
        pass

    def GetSashVisible(self):
        """"""
        pass

    def HasBorder(self):
        """"""
        pass

    def SetDefaultBorderSize(self):
        """"""
        pass

    def SetExtraBorderSize(self):
        """"""
        pass

    def SetMaximumSizeX(self):
        """"""
        pass

    def SetMaximumSizeY(self):
        """"""
        pass

    def SetMinimumSizeX(self):
        """"""
        pass

    def SetMinimumSizeY(self):
        """"""
        pass

    def SetSashBorder(self):
        """"""
        pass

    def SetSashVisible(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SashLayoutWindow(SashWindow):
    """"""

    def Create(self):
        """"""
        pass

    def GetAlignment(self):
        """"""
        pass

    def GetOrientation(self):
        """"""
        pass

    def SetAlignment(self):
        """"""
        pass

    def SetDefaultSize(self):
        """"""
        pass

    def SetOrientation(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SplitterWindow(Window):
    """"""

    def Create(self):
        """"""
        pass

    def GetBorderSize(self):
        """"""
        pass

    def GetMinimumPaneSize(self):
        """"""
        pass

    def GetNeedUpdating(self):
        """"""
        pass

    def GetSashPosition(self):
        """"""
        pass

    def GetSashSize(self):
        """"""
        pass

    def GetSplitMode(self):
        """"""
        pass

    def GetWindow1(self):
        """"""
        pass

    def GetWindow2(self):
        """"""
        pass

    def Initialize(self):
        """"""
        pass

    def IsSplit(self):
        """"""
        pass

    def ReplaceWindow(self):
        """"""
        pass

    def SetBorderSize(self):
        """"""
        pass

    def SetMinimumPaneSize(self):
        """"""
        pass

    def SetNeedUpdating(self):
        """"""
        pass

    def SetSashPosition(self):
        """"""
        pass

    def SetSashSize(self):
        """"""
        pass

    def SetSplitMode(self):
        """"""
        pass

    def SizeWindows(self):
        """"""
        pass

    def SplitHorizontally(self):
        """"""
        pass

    def SplitVertically(self):
        """"""
        pass

    def Unsplit(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


