"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Joystick.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
import Parameters as wx


class Joystick(Object):
    """"""

    def GetButtonState(self):
        """"""
        pass

    def GetManufacturerId(self):
        """"""
        pass

    def GetMaxAxes(self):
        """"""
        pass

    def GetMaxButtons(self):
        """"""
        pass

    def GetMovementThreshold(self):
        """"""
        pass

    def GetNumberAxes(self):
        """"""
        pass

    def GetNumberButtons(self):
        """"""
        pass

    def GetNumberJoysticks(self):
        """"""
        pass

    def GetPOVCTSPosition(self):
        """"""
        pass

    def GetPOVPosition(self):
        """"""
        pass

    def GetPollingMax(self):
        """"""
        pass

    def GetPollingMin(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def GetProductId(self):
        """"""
        pass

    def GetProductName(self):
        """"""
        pass

    def GetRudderMax(self):
        """"""
        pass

    def GetRudderMin(self):
        """"""
        pass

    def GetRudderPosition(self):
        """"""
        pass

    def GetUMax(self):
        """"""
        pass

    def GetUMin(self):
        """"""
        pass

    def GetUPosition(self):
        """"""
        pass

    def GetVMax(self):
        """"""
        pass

    def GetVMin(self):
        """"""
        pass

    def GetVPosition(self):
        """"""
        pass

    def GetXMax(self):
        """"""
        pass

    def GetXMin(self):
        """"""
        pass

    def GetYMax(self):
        """"""
        pass

    def GetYMin(self):
        """"""
        pass

    def GetZMax(self):
        """"""
        pass

    def GetZMin(self):
        """"""
        pass

    def GetZPosition(self):
        """"""
        pass

    def HasPOV(self):
        """"""
        pass

    def HasPOV4Dir(self):
        """"""
        pass

    def HasPOVCTS(self):
        """"""
        pass

    def HasRudder(self):
        """"""
        pass

    def HasU(self):
        """"""
        pass

    def HasV(self):
        """"""
        pass

    def HasZ(self):
        """"""
        pass

    def IsOk(self):
        """"""
        pass

    def ReleaseCapture(self):
        """"""
        pass

    def SetCapture(self):
        """"""
        pass

    def SetMovementThreshold(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

