"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: DataStructures.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx


class Point:
    """"""

    def Set(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __eq__(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __getitem__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __len__(self):
        """"""
        pass

    def __ne__(self):
        """"""
        pass

    def __nonzero__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass

    def __setitem__(self):
        """"""
        pass

    def __str__(self):
        """"""
        pass

    def __sub__(self):
        """"""
        pass

    def asTuple(self):
        """"""
        pass


class Point2DDouble:
    """"""

    def GetCrossProduct(self):
        """"""
        pass

    def GetDistance(self):
        """"""
        pass

    def GetDistanceSquare(self):
        """"""
        pass

    def GetDotProduct(self):
        """"""
        pass

    def GetFloor(self):
        """"""
        pass

    def GetRounded(self):
        """"""
        pass

    def GetVectorAngle(self):
        """"""
        pass

    def GetVectorLength(self):
        """"""
        pass

    def Normalize(self):
        """"""
        pass

    def SetPolarCoordinates(self):
        """"""
        pass

    def SetVectorAngle(self):
        """"""
        pass

    def SetVectorLength(self):
        """"""
        pass

    def __eq__(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __getitem__(self):
        """"""
        pass

    def __iadd__(self):
        """"""
        pass

    def __idiv__(self):
        """"""
        pass

    def __imul__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __isub__(self):
        """"""
        pass

    def __len__(self):
        """"""
        pass

    def __ne__(self):
        """"""
        pass

    def __neg__(self):
        """"""
        pass

    def __nonzero__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass

    def __setitem__(self):
        """"""
        pass

    def __str__(self):
        """"""
        pass

    def asTuple(self):
        """"""
        pass


class RealPoint:
    """"""

    def Set(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __eq__(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __getitem__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __len__(self):
        """"""
        pass

    def __ne__(self):
        """"""
        pass

    def __nonzero__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass

    def __setitem__(self):
        """"""
        pass

    def __str__(self):
        """"""
        pass

    def __sub__(self):
        """"""
        pass

    def asTuple(self):
        """"""
        pass


class Rect:
    """"""

    def GetBottom(self):
        """"""
        pass

    def GetHeight(self):
        """"""
        pass

    def GetLeft(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def GetRight(self):
        """"""
        pass

    def GetSize(self):
        """"""
        pass

    def GetTop(self):
        """"""
        pass

    def GetWidth(self):
        """"""
        pass

    def GetX(self):
        """"""
        pass

    def GetY(self):
        """"""
        pass

    def Inflate(self):
        """"""
        pass

    def Inside(self):
        """"""
        pass

    def SetBottom(self):
        """"""
        pass

    def SetHeight(self):
        """"""
        pass

    def SetLeft(self):
        """"""
        pass

    def SetPosition(self):
        """"""
        pass

    def SetRight(self):
        """"""
        pass

    def SetSize(self):
        """"""
        pass

    def SetTop(self):
        """"""
        pass

    def SetWidth(self):
        """"""
        pass

    def SetX(self):
        """"""
        pass

    def SetY(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __eq__(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __getitem__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __len__(self):
        """"""
        pass

    def __ne__(self):
        """"""
        pass

    def __nonzero__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass

    def __setitem__(self):
        """"""
        pass

    def __str__(self):
        """"""
        pass

    def asTuple(self):
        """"""
        pass


class Size:
    """"""

    def GetHeight(self):
        """"""
        pass

    def GetWidth(self):
        """"""
        pass

    def GetX(self):
        """"""
        pass

    def GetY(self):
        """"""
        pass

    def Set(self):
        """"""
        pass

    def SetHeight(self):
        """"""
        pass

    def SetWidth(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __eq__(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __getitem__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __len__(self):
        """"""
        pass

    def __ne__(self):
        """"""
        pass

    def __nonzero__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass

    def __setitem__(self):
        """"""
        pass

    def __str__(self):
        """"""
        pass

    def asTuple(self):
        """"""
        pass


